==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/ClusterOperatorListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterOperatorListBuilder extends io.fabric8.openshift.api.model.ClusterOperatorListFluentImpl<io.fabric8.openshift.api.model.ClusterOperatorListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterOperatorList,io.fabric8.openshift.api.model.ClusterOperatorListBuilder>{
  public ClusterOperatorListBuilder() {
    this(false);
  }
  public ClusterOperatorListBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterOperatorList(), validationEnabled);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterOperatorList(), validationEnabled);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperatorList instance) {
    this(fluent, instance, false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorList instance) {
    this(instance,false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterOperatorList build() {
    ClusterOperatorList buildable = new ClusterOperatorList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterOperatorListBuilder that = (ClusterOperatorListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ClusterOperatorListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterOperatorListBuilder extends io.fabric8.openshift.api.model.ClusterOperatorListFluentImpl<io.fabric8.openshift.api.model.ClusterOperatorListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterOperatorList,io.fabric8.openshift.api.model.ClusterOperatorListBuilder>{
  public ClusterOperatorListBuilder() {
    this(false);
  }
  public ClusterOperatorListBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterOperatorList(), validationEnabled);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterOperatorList(), validationEnabled);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperatorList instance) {
    this(fluent, instance, false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent,io.fabric8.openshift.api.model.ClusterOperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorList instance) {
    this(instance,false);
  }
  public ClusterOperatorListBuilder(io.fabric8.openshift.api.model.ClusterOperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterOperatorListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterOperatorList build() {
    ClusterOperatorList buildable = new ClusterOperatorList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterOperatorListBuilder that = (ClusterOperatorListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
